==> paraview-5.12.1-9-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/StreamLinesRepresentation-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_depends" "ParaView::RemotingViews;ParaView::VTKExtensionsMisc;VTK::CommonCore;VTK::RenderingCore")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_private_depends" "ParaView::VTKExtensionsFiltersRendering;VTK::CommonCore;VTK::CommonDataModel;VTK::CommonExecutionModel;VTK::CommonMath;VTK::CommonTransforms;VTK::RenderingCore;VTK::RenderingOpenGL2;VTK::glew;VTK::opengl")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_library_name" "vtkStreamLines")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkStreamLinesMapper.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkStreamLinesRepresentation.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkStreamLinesModule.h")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/StreamLinesRepresentation/vtk/hierarchy/StreamLinesRepresentation/vtkStreamLines-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.3-4-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/StreamLinesRepresentation-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_depends" "ParaView::RemotingViews;ParaView::VTKExtensionsMisc;VTK::CommonCore;VTK::RenderingCore")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_private_depends" "ParaView::VTKExtensionsFiltersRendering;VTK::CommonCore;VTK::CommonDataModel;VTK::CommonExecutionModel;VTK::CommonMath;VTK::CommonTransforms;VTK::RenderingCore;VTK::RenderingOpenGL2;VTK::glew;VTK::opengl")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_library_name" "vtkStreamLines")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_forward_link" "VTK::PythonUsed")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkStreamLinesMapper.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkStreamLinesRepresentation.h")
set_property(TARGET "StreamLinesRepresentation::vtkStreamLines" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/StreamLinesRepresentation/vtk/hierarchy/StreamLinesRepresentation/vtkStreamLines-hierarchy.txt")
unset(_vtk_module_import_prefix)
